@@ -1,15 +1,14 @@
 ;;; logms.el --- Log message with clickable links to context  -*- lexical-binding: t; -*-
 
-;; Copyright (C) 2021  Shen, Jen-Chieh
+;; Copyright (C) 2021-2026  Shen, Jen-Chieh
 ;; Created date 2021-06-26 23:22:27
 
 ;; Author: Shen, Jen-Chieh <jcs090218@gmail.com>
-;; Description: Log message with clickable links to context
-;; Keyword: debug log
-;; Package-Version: 0.3.1
-;; Package-Revision: 68bab96a13d6
-;; Package-Requires: ((emacs "27.1") (f "0.20.0") (s "1.9.0") (ht "2.3"))
 ;; URL: https://github.com/jcs-elpa/logms
+;; Package-Version: 20260101.600
+;; Package-Revision: 7f430ce289d4
+;; Package-Requires: ((emacs "27.1") (f "0.20.0") (s "1.9.0") (ht "2.3"))
+;; Keywords: maint debug log
 
 ;; This file is NOT part of GNU Emacs.
 
@@ -262,9 +261,9 @@ This is use to resolve when logms are pass in with variables."
 Note there is no way you can track timer event since you cannot track a
 delay function and expect to record states (window/frame/cursor, etc) that
 already happened."
-  (dolist (frame frames)
-    (when (equal (backtrace-frame-fun frame) 'timer-event-handler)
-      (user-error "[WARNING] Timer event are not allow to `logms`"))))
+  (cl-some (lambda (frame)
+             (equal (backtrace-frame-fun frame) 'timer-event-handler))
+           frames))
 
 (defun logms--last-call-stack-backtrace ()
   "Return the last stack frame right before of the logms function begin called.
@@ -275,7 +274,6 @@ It returns cons cell from by (current frame . backtrace)."
   (let* ((frames (backtrace-get-frames 'logms)) (frames-len (length frames))
          (backtrace (list (nth 0 frames)))  ; always has the base frame
          (index 1) break frame evald fun)
-    (logms--backtrace-timer-event frames)
     (while (and (not break) (< index frames-len))
       (setq frame (nth index frames)
             evald (backtrace-frame-evald frame)
@@ -291,6 +289,19 @@ It returns cons cell from by (current frame . backtrace)."
                             (and (symbolp caller)
                                  (member (symbol-name caller) logms--ignore-rule))))
                         backtrace))
+    (when (and (logms--backtrace-timer-event frames)  ; Is timer event?
+               (or
+                ;; If nearest frame is timer event, it has been called directly
+                ;; like the following
+                ;;
+                ;;   (run-with-timer 1 nil #'logms SOME-TEXT)
+                (and (symbolp fun) (eq fun 'timer-event-handler))
+                ;; If nearest frame is lambda, it has been called with lambda
+                ;; wrapper,
+                ;;
+                ;;   (run-with-timer 1 nil (lambda () (logms SOME-TEXT)))
+                (and (consp fun) (symbolp (car fun)) (eq (car fun) 'lambda))))
+      (user-error "[WARNING] Invalid timer event to `logms`, please define a valid source"))
     ;; FRAME is the up one level call stack. BACKTRACE is used to compare
     ;; the frame level.
     (cons frame (reverse backtrace))))
@@ -408,13 +419,13 @@ Argument PT indicates where the log beging print inside SOURCE buffer."
            (c-inter (eq caller this-command)) start)
 
       (save-window-excursion
-        ;; * If symbol, there is defined call stack we cal look for; unless
+        ;; * If symbol, there is defined call stack we can look for; unless
         ;; it's compiled and the source is from C code.
         ;;
         ;; * If not symbol, it's evaluate somewhere in memory
         ;;
         ;; * Excluding `funcall` and `apply`, both functions are compiled hence
-        ;; the source if from C code.  (See bullet Pt. 1)
+        ;; the source is from C code.  (See bullet Pt. 1)
         (when (and (symbolp caller)
                    (not (memq caller logms--ignore-call-frame)))
           (add-hook 'find-function-after-hook (lambda () (setq found t)))
